@@ -2,7 +2,9 @@ from __future__ import annotations
 
 
 __all__ = [
+    'rationals',
     'coprime_pairs',
+    'FareyFraction',
     'farey_sequence',
     'KSRMTree',
 ]
@@ -12,60 +14,370 @@ __all__ = [
 
 # -- Standard libraries --
 import math
-import sys
 import typing
 
-from itertools import chain, product, starmap
-from pathlib import Path
+from itertools import chain
 
 # -- 3rd party libraries --
 
 # -- Internal libraries --
-sys.path.insert(0, str(Path(__file__).parent.parent))
-
 from continuedfractions.utils import NamedCallableProxy
 from continuedfractions.continuedfraction import ContinuedFraction
 
-KSRMNode: typing.TypeAlias = tuple[int, int]   #: Custom type for nodes of the KSRM coprime pairs tree
-KSRMBranch: NamedCallableProxy          #: Custom type for generating branches of the KSRM coprime pairs tree
+
+def rationals(
+    enumeration: typing.Literal["cantor diagonal", "cantor diagonal transposed", "rectilinear", "rectilinear transposed"],
+    positive_only: bool = True
+) -> typing.Generator[ContinuedFraction, None, None]:
+    """:py:class:`typing.Generator` : An enumerator of rational numbers :math:`\\mathbb{Q}` using an enumeration on Cantor's 2D representation of the rationals.
+
+    By default it generates sequences of all positive rational numbers as
+    :py:class:`~continuedfractions.continuedfractions.ContinuedFraction`
+    objects with the user-specified enumeration on Cantor's 2D
+    representation of the rationals as described in the
+    `documentation <https://continuedfractions.readthedocs.io/sources/sequences.html#rationals>`_.
+
+    To include negative rationals and :math:`0` set ``positive_only`` to
+    ``False``, as described in the documentation and the docstring examples
+    below.
+
+    The enumeration type should be given by the ``enumeration`` argument, which
+    should be one of the following:
+
+    * ``"cantor diagonal"``: for the standard way of enumerating rational
+    numbers using Cantor diagonalisation (with ``positive_only=False``):
+    
+    .. math::
+
+        \\frac{1}{1}, \\frac{2}{1}, \\frac{1}{2}, \\frac{1}{3}, \\frac{3}{1}, \\frac{4}{1}, \\frac{3}{2}, \\frac{2}{3}, \\frac{1}{4}, \\ldots
+
+    * ``"cantor diagonal transposed"``: similar to the standard Cantor
+    diagonalisation (with ``positive_only=False``), except the enumeration
+    proceeds:
+    ::
+
+        right 1 step ->
+        diagonal down 1 step ->
+        down 1 step ->
+        diagonal up 2 steps ->
+        ...
+    
+    and produces the sequence:
+
+    .. math::
+
+        \\frac{1}{1}, \\frac{1}{2}, \\frac{2}{1}, \\frac{3}{1}, \\frac{1}{3}, \\frac{1}{4}, \\frac{2}{3}, \\frac{3}{2}, \\frac{4}{1}, \\ldots
+
+    * ``"rectilinear"``: an enumeration which proceeds in a reverse L-shaped
+    way (with ``positive_only=False``):
+    ::
+
+        down 1 step  ->
+        right 1 step -> up 1 step   -> right 1 step ->
+        down 2 steps -> left 2 steps -> down 1 step ->
+        right 3 steps -> up 3 steps -> right 1 step ->
+        down 4 steps  -> left 4 steps -> down 1 step ->
+        ...
+
+    and produces the sequence: 
+    
+    .. math::
+
+       \\frac{1}{1}, \\frac{2}{1}, \\frac{1}{2}, \\frac{1}{3}, \\frac{2}{3}, \\frac{3}{2}, \\frac{3}{1}, \\frac{4}{1}, \\ldots
+
+    * ``"rectilinear transposed"``: an enumeration similar to ``"rectilinear"``
+    (with ``positive_only=False``) except the enumeration proceeds:
+    ::
+
+        right 1 step  ->
+        down 1 step -> left 1 step   -> down 1 step ->
+        right 2 steps -> up 2 steps -> right 1 step ->
+        down 3 steps -> left 3 steps -> down 1 step ->
+        right 4 steps  -> up 4 steps -> right 1 step ->
+        ...
+    
+    and produces the sequence:
+    
+    .. math::
+
+       \\frac{1}{1}, \\frac{1}{2}, \\frac{2}{1}, \\frac{3}{1}, \\frac{3}{2}, \\frac{2}{3}, \\frac{1}{3}, \\frac{1}{4}, \\ldots
+
+    Parameters
+    ----------
+    enumeration : str
+        A string literal which describes how the rationals should be
+        enumerated:
+
+        * ``"cantor diagonal"``
+        * ``"cantor diagonal transposed"``
+        * ``"rectilinear"``
+        * ``"rectilinear transposed"``
+
+        These enumerations are described above in the docstring, and also in
+        the `Sphinx documentation <https://continuedfractions.readthedocs.io/sources/pythagorean-triples.html#primitive-pythagorean-triples>`_
+
+    positive_only : bool, default=True
+        Whether to generate only the positive rationals, which is true by
+        default.
+
+    Yields
+    ------
+    ContinuedFraction
+        The rational numbers are generated as
+        :py:class:`~continuedfractions.continuedfraction.ContinuedFraction`
+        objects.
+
+    Raises
+    ------
+    ValueError
+        If ``enumeration`` is not an unrecognised or unsupported enumeration.
+
+    Examples
+    --------
+    >>> rats = rationals(enumeration="cantor diagonal")
+    >>> first_ten = [next(rats) for _ in range(10)]
+    >>> first_ten
+    [ContinuedFraction(1, 1), ContinuedFraction(2, 1), ContinuedFraction(1, 2), ContinuedFraction(1, 3), ContinuedFraction(3, 1), ContinuedFraction(4, 1), ContinuedFraction(3, 2), ContinuedFraction(2, 3), ContinuedFraction(1, 4), ContinuedFraction(1, 5)]
+    >>> rats = rationals(enumeration="cantor diagonal", positive_only=False)
+    >>> first_ten_plus_zero = [next(rats) for _ in range(11)]
+    >>> first_ten_plus_zero
+    [ContinuedFraction(0, 1), ContinuedFraction(1, 1), ContinuedFraction(-1, 1), ContinuedFraction(2, 1), ContinuedFraction(-2, 1), ContinuedFraction(1, 2), ContinuedFraction(-1, 2), ContinuedFraction(1, 3), ContinuedFraction(-1, 3), ContinuedFraction(3, 1), ContinuedFraction(-3, 1)]
+    >>> rats = rationals(enumeration="cantor diagonal transposed")
+    >>> first_ten = [next(rats) for _ in range(10)]
+    >>> first_ten
+    [ContinuedFraction(1, 1), ContinuedFraction(1, 2), ContinuedFraction(2, 1), ContinuedFraction(3, 1), ContinuedFraction(1, 3), ContinuedFraction(1, 4), ContinuedFraction(2, 3), ContinuedFraction(3, 2), ContinuedFraction(4, 1), ContinuedFraction(5, 1)]
+    >>> rats = rationals(enumeration="cantor diagonal transposed", positive_only=False)
+    >>> first_ten_plus_zero = [next(rats) for _ in range(11)]
+    >>> first_ten_plus_zero
+    [ContinuedFraction(0, 1), ContinuedFraction(1, 1), ContinuedFraction(-1, 1), ContinuedFraction(1, 2), ContinuedFraction(-1, 2), ContinuedFraction(2, 1), ContinuedFraction(-2, 1), ContinuedFraction(3, 1), ContinuedFraction(-3, 1), ContinuedFraction(1, 3), ContinuedFraction(-1, 3)]
+    >>> rats = rationals(enumeration="rectilinear")
+    >>> first_ten = [next(rats) for _ in range(10)]
+    >>> first_ten
+    [ContinuedFraction(1, 1), ContinuedFraction(2, 1), ContinuedFraction(1, 2), ContinuedFraction(1, 3), ContinuedFraction(2, 3), ContinuedFraction(3, 2), ContinuedFraction(3, 1), ContinuedFraction(4, 1), ContinuedFraction(4, 3), ContinuedFraction(3, 4)]
+    >>> rats = rationals(enumeration="rectilinear", positive_only=False)
+    >>> first_ten_plus_zero = [next(rats) for _ in range(11)]
+    >>> first_ten_plus_zero
+    [ContinuedFraction(0, 1), ContinuedFraction(1, 1), ContinuedFraction(-1, 1), ContinuedFraction(2, 1), ContinuedFraction(-2, 1), ContinuedFraction(1, 2), ContinuedFraction(-1, 2), ContinuedFraction(1, 3), ContinuedFraction(-1, 3), ContinuedFraction(2, 3), ContinuedFraction(-2, 3)]
+    >>> rats = rationals(enumeration="rectilinear transposed", positive_only=False)
+    >>> first_ten_plus_zero = [next(rats) for _ in range(11)]
+    >>> first_ten_plus_zero
+    [ContinuedFraction(0, 1), ContinuedFraction(1, 1), ContinuedFraction(-1, 1), ContinuedFraction(1, 2), ContinuedFraction(-1, 2), ContinuedFraction(2, 1), ContinuedFraction(-2, 1), ContinuedFraction(3, 1), ContinuedFraction(-3, 1), ContinuedFraction(3, 2), ContinuedFraction(-3, 2)]
+    >>> rats = rationals(enumeration="some unknown enumeration")
+    >>> next(rats)
+    Traceback (most recent call last):
+    ...
+    ValueError: The value of `enumeration` should be one of the following: "cantor diagonal", "cantor diagonal transposed", "rectilinear" or "rectilinear transposed".
+    """
+    # Validation of the ``enumeration`` argument.
+    enumeration_ = enumeration.strip().lower()
+    if enumeration_ not in [
+        "cantor diagonal", "cantor diagonal transposed", "rectilinear", "rectilinear transposed"
+    ]:
+        raise ValueError(
+            'The value of `enumeration` should be one of the following: '
+            '"cantor diagonal", "cantor diagonal transposed", "rectilinear" '
+            'or "rectilinear transposed".'
+        )
+
+    if enumeration_ == "cantor diagonal" and positive_only:
+        # The diagonal index, starting at ``n = 1``: the first diagonal `D1`
+        # which is just ``1/1``.
+        n = 1
+        yield ContinuedFraction(1, 1)
+
+        while True:
+            # Increment the diagonal index, and generate the new diagonal:
+            # the diagonal ``D_n`` is given by:
+            #
+            #     n/1, (n - 1)/2, (n - 2)/3, ... , 1/n
+            #
+            # if ``n`` is even, while if ``n`` is odd it is given by:
+            #
+            #    1/n, 2/(n - 1), 3/(n - 2), ... , n/1
+            #
+            n += 1
+            us = range(n, 0, -1) if n % 2 == 0 else range(1, n + 1)
+            vs = range(1, n + 1) if n % 2 == 0 else range(n, 0, -1)
+            yield from (ContinuedFraction(u, v) for u, v in zip(us, vs) if math.gcd(u, v) == 1)
+    elif enumeration_ == "cantor diagonal" and not positive_only:
+        # When ``positive_only`` is ``False`` we start by generating the
+        # ``ContinuedFraction`` object for ``0``.
+        yield ContinuedFraction(0, 1)
+        n = 0
+
+        while True:
+            # Same process as for ``"cantor diagonal"``, except that for each
+            # coprime pair ``(u, v)`` on the ``n``-th diagonal we generate the
+            # negative continued fraction ``-u/v`` immediately after the
+            # positive continued fraction ``u/v``.
+            n += 1
+            us = range(n, 0, -1) if n % 2 == 0 else range(1, n + 1)
+            vs = range(1, n + 1) if n % 2 == 0 else range(n, 0, -1)
+            pos_rationals = (ContinuedFraction(u, v) for u, v in zip(us, vs) if math.gcd(u, v) == 1)
+            yield from chain.from_iterable(((r, -r) for r in pos_rationals))
+    elif enumeration_ == "cantor diagonal transposed" and positive_only:
+        # The diagonal index, starting at ``n = 1``: the first diagonal `D1`
+        # which is just ``1/1``.
+        n = 1
+        yield ContinuedFraction(1, 1)
+
+        while True:
+            # Increment the diagonal index, and generate the new diagonal:
+            # the diagonal ``D_n`` is given by:
+            #     1/n, 2/(n - 1), 3/(n - 2), ... , n/1  
+            # 
+            # if ``n`` is even, while if ``n`` is odd it is given by:
+            #
+            #     n/1, (n - 1)/2, (n - 2)/3, ... , 1/n
+            #
+            n += 1
+            us = range(1, n + 1) if n % 2 == 0 else range(n, 0, -1)
+            vs = range(n, 0, -1) if n % 2 == 0 else range(1, n + 1)
+            yield from (ContinuedFraction(u, v) for u, v in zip(us, vs) if math.gcd(u, v) == 1)
+    elif enumeration_ == "cantor diagonal transposed" and not positive_only:
+        # When ``positive_only`` is ``False`` we start by generating the
+        # ``ContinuedFraction`` object for ``0``.
+        yield ContinuedFraction(0, 1)
+        n = 0
+
+        while True:
+            # Same process as for ``"cantor diagonal transposed"``, except that
+            # for each coprime pair ``(u, v)`` on the ``n``-th diagonal we
+            # generate the negative continued fraction ``-u/v`` immediately
+            # after the positive continued fraction ``u/v``.
+            n += 1
+            us = range(1, n + 1) if n % 2 == 0 else range(n, 0, -1)
+            vs = range(n, 0, -1) if n % 2 == 0 else range(1, n + 1)
+            pos_rationals = (ContinuedFraction(u, v) for u, v in zip(us, vs) if math.gcd(u, v) == 1)
+            yield from chain.from_iterable(((r, -r) for r in pos_rationals))
+    elif enumeration_ == "rectilinear" and positive_only:
+        # The initial reverse-L index, starting at ``n = 1``: this will
+        # generate ``1/1``.
+        n = 1
+        yield ContinuedFraction(1, 1)
+
+        while True:
+            # Increment the reverse-L index, and enumerate the rationals (as
+            # described in the documentation) from the  reverse Ls ``⅃_n`` first
+            # by first chaining the subsequences ``⅃_{n,1}`` and ``⅃_{n,2}``,
+            # both of length ``2n - 1``, to produce the chained subsequence:
+            #
+            #     n/1, n/2, n/3, ... , n/n, (n - 1)/n, (n - 2)/n, (n - 3)/n, ... , 1/n
+            # 
+            # if ``n`` is even, or, if ``n`` is odd, as:
+            #
+            #     1/n, 2/n, 3/n, ... , n/n, n/(n - 1), n/(n - 2), n/(n - 3), ... , n/1
+            #
+            # and then filtering out composite fractions ``u/v`` in the chained
+            # subsequence, i.e. applying ``math.gcd(u, v) == 1``. 
+            #
+            n += 1
+            us = (
+                chain((n for _ in range(n)), range(n - 1, 0, -1))
+                if n % 2 == 0 else 
+                chain(range(1, n + 1), (n for _ in range(n - 1)))
+            )
+            vs = (
+                chain(range(1, n + 1), (n for _ in range(n - 1)))
+                if n % 2 == 0 else
+                chain((n for _ in range(n)), range(n - 1, 0, -1))
+            )
+            yield from (ContinuedFraction(u, v) for u, v in zip(us, vs) if math.gcd(u, v) == 1)
+    elif enumeration_ == "rectilinear" and not positive_only:
+        # When ``positive_only`` is ``False`` we start by generating the
+        # ``ContinuedFraction`` object for ``0``.
+        yield ContinuedFraction(0, 1)
+        n = 0
+
+        while True:
+            # Same process as for ``"rectilinear"``, except that for each
+            # coprime pair ``(u, v)`` on the ``n``-th reverse L ``⅃_n`` we
+            # generate the negative continued fraction ``-u/v`` immediately
+            # after the positive continued fraction ``u/v``.
+            n += 1
+            us = (
+                chain((n for _ in range(n)), range(n - 1, 0, -1))
+                if n % 2 == 0 else 
+                chain(range(1, n + 1), (n for _ in range(n - 1)))
+            )
+            vs = (
+                chain(range(1, n + 1), (n for _ in range(n - 1)))
+                if n % 2 == 0 else
+                chain((n for _ in range(n)), range(n - 1, 0, -1))
+            )
+            pos_rationals = (ContinuedFraction(u, v) for u, v in zip(us, vs) if math.gcd(u, v) == 1)
+            yield from chain.from_iterable(((r, -r) for r in pos_rationals))
+    elif enumeration_ == "rectilinear transposed" and positive_only:
+        # The initial reverse-L index, starting at ``n = 1``: this will
+        # generate ``1/1``.
+        n = 1
+        yield ContinuedFraction(1, 1)
+
+        while True:
+            # Increment the reverse-L index, and enumerate the rationals (as
+            # described in the documentation) from the  reverse Ls ``⅃_n`` first
+            # by first chaining the subsequences ``⅃_{n,1}`` and ``⅃_{n,2}``,
+            # both of length ``2n - 1``, to produce the chained subsequence:
+            #
+            #     1/n, 2/n, 3/n, ... , n/n, n/(n - 1), n/(n - 2), n/(n - 3), ... , n/1
+            # 
+            # if ``n`` is even, or, if ``n`` is odd, as:
+            #
+            #     n/1, n/2, n/3, ... , n/n, (n - 1)/n, (n - 2)/n, (n - 3)/n, ... , 1/n
+            #
+            # and then filtering out composite fractions ``u/v`` in the chained
+            # subsequence, i.e. applying ``math.gcd(u, v) == 1``.
+            n += 1
+            us = (
+                chain(range(1, n), (n for _ in range(n)))
+                if n % 2 == 0 else
+                chain((n for _ in range(n)), range(n - 1, 0, -1))
+            )
+            vs = (
+                chain((n for _ in range(n - 1)), range(n, 0, -1))
+                if n % 2 == 0 else
+                chain(range(1, n + 1), (n for _ in range(n - 1)))
+            )
+            yield from (ContinuedFraction(u, v) for u, v in zip(us, vs) if math.gcd(u, v) == 1)
+    elif enumeration_ == "rectilinear transposed" and not positive_only:
+        # When ``positive_only`` is ``False`` we start by generating the
+        # ``ContinuedFraction`` object for ``0``.
+        yield ContinuedFraction(0, 1)
+        n = 0
+
+        while True:
+            # Same process as for ``"rectilinear transposed"``, except that
+            # for each coprime pair ``(u, v)`` on the ``n``-th reverse L
+            # ``⅃_n`` we generate the negative continued fraction ``-u/v``
+            # immediately after the positive continued fraction ``u/v``. 
+            n += 1
+            us = (
+                chain(range(1, n), (n for _ in range(n)))
+                if n % 2 == 0 else
+                chain((n for _ in range(n)), range(n - 1, 0, -1))
+            )
+            vs = (
+                chain((n for _ in range(n - 1)), range(n, 0, -1))
+                if n % 2 == 0 else
+                chain(range(1, n + 1), (n for _ in range(n - 1)))
+            )
+            pos_rationals = (ContinuedFraction(u, v) for u, v in zip(us, vs) if math.gcd(u, v) == 1)
+            yield from chain.from_iterable(((r, -r) for r in pos_rationals))
+
+    return  # pragma: no cover
 
 
-def _coprime_integers(n: int, /, *, start: int = 1, stop: int = None) -> typing.Generator[int, None, None]:
+def _coprime_integers(n: int, /) -> typing.Generator[int, None, None]:
     """Generates a sequence of (positive) integers :math:`1 \\leq m < n` coprime to a given positive integer :math:`n`.
 
     The tuple is sorted in descending order of magnitude.
 
-    The optional ``start`` and ``stop`` parameters can be used to bound the
-    the range of (positive) integers in which integers coprime to the given
-    :math:`n` are sought.
-
-    For :math:`n = 1, 2` the ``start`` value is effectively ignored, but
-    if :math:`n > 1` then the ``start`` value must be an integer in the range
-    :math:`1..n - 1`.
-
-    The ``stop`` value defaults to ``None``, which is then internally
-    initialised to :math:`n`; if :math:`n > 1` and ``stop`` is given then it
-    must be an integer in the range :math:`\\text{start} + 1..n`.
-
     Parameters
     ----------
     n : int
         The positive integer for which (positive) coprime integers
         :math:`m < n` are sought.
 
-    start : int, default=1
-        The lower bound of the range of (positive) integers in which integers
-        coprime to the given :math:`n` are sought. For :math:`n = 1, 2` the
-        ``start`` value is effectively ignored, but if :math:`n > 1` then the
-        ``start`` value must be in the range :math:`1..n - 1`.
-
-    stop : int, default=None
-        The upper bound of the range of (positive) integers in which integers
-        coprime to the given :math:`n` are sought. The ``stop`` value defaults
-        to ``None``, which is then internally initialised to :math:`n`; if
-        :math:`n > 1` and ``stop`` is given then it must be an integer in the
-        range :math:`\\text{start} + 1..n`.
-
     Raises
     ------
     ValueError
@@ -86,61 +398,13 @@ def _coprime_integers(n: int, /, *, start: int = 1, stop: int = None) -> typing.
 
     >>> tuple(_coprime_integers(1))
     (1,)
-    >>> tuple(_coprime_integers(2))
-    (1,)
-    >>> tuple(_coprime_integers(3))
-    (2, 1)
-    >>> tuple(_coprime_integers(4))
-    (3, 1)
     >>> tuple(_coprime_integers(5))
     (4, 3, 2, 1)
-    >>> tuple(_coprime_integers(6))
-    (5, 1)
-    >>> tuple(_coprime_integers(7))
-    (6, 5, 4, 3, 2, 1)
-    >>> tuple(_coprime_integers(8))
-    (7, 5, 3, 1)
-    >>> tuple(_coprime_integers(9))
-    (8, 7, 5, 4, 2, 1)
     >>> tuple(_coprime_integers(10))
     (9, 7, 3, 1)
-    >>> tuple(_coprime_integers(11))
-    (10, 9, 8, 7, 6, 5, 4, 3, 2, 1)
 
-    Examples using custom ``start`` and ``stop`` values:
-
-    >>> tuple(_coprime_integers(3, start=0))
-    Traceback (most recent call last):
-    ...
-    ValueError: `n` must be a positive integer; if `n` > 1 then the `start` value must be a positive integer in the range 1..n - 1; and if given the `stop` value must be a positive integer in the range `start` + 1..n
-    >>> tuple(_coprime_integers(3, start=2))
-    (2,)
-    >>> tuple(_coprime_integers(3, start=3))
-    Traceback (most recent call last):
-    ...
-    ValueError: `n` must be a positive integer; if `n` > 1 then the `start` value must be a positive integer in the range 1..n - 1; and if given the `stop` value must be a positive integer in the range `start` + 1..n
-    >>> tuple(_coprime_integers(23, start=5, stop=21))
-    (21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5)
-    >>> tuple(_coprime_integers(5, start=2))
-    (4, 3, 2)
-    >>> tuple(_coprime_integers(5, start=3))
-    (4, 3)
-    >>> tuple(_coprime_integers(6, start=2))
-    (5,)
-    >>> tuple(_coprime_integers(6, start=3))
-    (5,)
-    >>> tuple(_coprime_integers(6, start=4))
-    (5,)
-    >>> tuple(_coprime_integers(7, start=2))
-    (6, 5, 4, 3, 2)
-    >>> tuple(_coprime_integers(7, start=3))
-    (6, 5, 4, 3)
-    >>> tuple(_coprime_integers(7, start=4))
-    (6, 5, 4)
-    >>> tuple(_coprime_integers(7, start=5))
-    (6, 5)
     """
-    if not isinstance(n, int) or n < 1 or (n > 1 and start not in range(1, n)) or (n > 1 and stop and stop not in range(start + 1, n + 1)):
+    if not isinstance(n, int) or n < 1:
         raise ValueError(
             "`n` must be a positive integer; if `n` > 1 then the "
             "`start` value must be a positive integer in the range 1..n - 1; "
@@ -148,29 +412,11 @@ def _coprime_integers(n: int, /, *, start: int = 1, stop: int = None) -> typing.
             "range `start` + 1..n"
         )
 
-    if n in (1, 2):
-        yield 1
-    else:
-        chunklen = 1000
-        stop = stop or n
-        q, r = divmod((stop - start + 1), chunklen)
+    yield from (m for m in range(n, 0, -1) if math.gcd(m, n) == 1)
 
-        if q == 0:
-            yield from filter(
-                lambda m: math.gcd(m, n) == 1,
-                range(stop, start - 1, -1)
-            )
-        else:
-            _start = ((chunklen) * q) + (1 if r > 0 else 0)
-            
-            while _start >= start:
-                yield from filter(
-                    lambda m: math.gcd(m, n) == 1,
-                    range(stop, _start - 1, -1)
-                )
-                stop = _start - 1
-                q -= 1
-                _start = ((chunklen) * q) + 1
+
+KSRMTreeNode: typing.TypeAlias = tuple[int, int]        #: Custom type for nodes of the KSRM coprime pairs tree
+KSRMTreeBranch: typing.TypeAlias = NamedCallableProxy   #: Custom type for generating branches of the KSRM coprime pairs tree
 
 
 class KSRMTree:
@@ -201,9 +447,9 @@ class KSRMTree:
     # two roots ``(2, 1), (3, 1)``, and the three branch generating functions.
     __slots__ = ('_roots', '_branches')
 
-    _roots: tuple[KSRMNode, KSRMNode]
+    _roots: tuple[KSRMTreeNode, KSRMTreeNode]
 
-    _branches: tuple[KSRMBranch]    # noqa: F821
+    _branches: tuple[KSRMTreeBranch]    # noqa: F821
 
     def __new__(cls) -> KSRMTree:
         """Class constructor.
@@ -223,7 +469,7 @@ class KSRMTree:
         return self
 
     @property
-    def roots(self) -> typing.Literal[tuple([(2, 1), (3, 1)])]:
+    def roots(self) -> typing.Literal[((2, 1), (3, 1))]:
         """:py:class:`tuple`: The tuple of roots of the KSRM trees, which are :math:`(2, 1)` and :math:`(3, 1)`.
 
         For more details see the following papers:
@@ -242,7 +488,7 @@ class KSRMTree:
         return self._roots
 
     @property
-    def branches(self) -> tuple[KSRMBranch]:    # noqa: F821
+    def branches(self) -> tuple[KSRMTreeBranch]:    # noqa: F821
         """:py:class:`tuple`: The tuple of three branch generating functions of the KSRM trees.
 
         There are three branch generating functions, given by the mappings:
@@ -301,11 +547,11 @@ class KSRMTree:
     def _backtrack(
         self,
         n: int,
-        visited: list[tuple[KSRMNode, KSRMBranch]],     # noqa: F821
+        visited: list[tuple[KSRMTreeNode, KSRMTreeBranch]],     # noqa: F821
         /,
         *,
         node_bound: int = None
-    ) -> tuple[KSRMNode, KSRMBranch, int, KSRMBranch]:  # noqa: F821
+    ) -> tuple[KSRMTreeNode, KSRMTreeBranch, int, KSRMTreeBranch]:  # noqa: F821
         """Backtracks on the KSRM coprime pairs trees from a failed node to the nearest previously visited node that satisfies the node bound.
 
         A private function that backtracks on the KSRM coprime pairs trees: the
@@ -420,7 +666,7 @@ class KSRMTree:
         # branch of the last visited node before the current node.
         return cur_node, cur_branch, cur_index, last_branch
 
-    def search_root(self, n: int, root: KSRMNode, /) -> typing.Generator[KSRMNode, None, None]:
+    def search_root(self, n: int, root: KSRMTreeNode, /) -> typing.Generator[KSRMTreeNode, None, None]:
         """Depth-first branch-and-bound generative search function (in pre-order, NLMR), with backtracking and pruning, on the KSRM coprime pairs trees, starting from the given root node.
 
         The given root node need not be the canonical roots, :math:`(2, 1)`,
@@ -571,16 +817,16 @@ class KSRMTree:
 
                 # Otherwise, switch to the generating branch of the "next"
                 # child node - branch #2 if the current branch is branch #1, or
-                # branch #3 if the current branch is #2 - and continue the
-                # search.
-                cur_branch = self.branches[1] if last_branch == self.branches[0] else self.branches[-1]
+                # branch #3 (the last branch) if the current branch is #2 - and
+                # continue the DFS.
+                cur_branch = self.branches[1] if last_branch.name == self.branches[0].name else self.branches[-1]
                 continue
 
         # Not strictly required, but this has been inserted to make
         # debugging easier.
         return
 
-    def search(self, n: int, /) -> typing.Generator[KSRMNode, None, None]:
+    def search(self, n: int, /) -> typing.Generator[KSRMTreeNode, None, None]:
         """Depth-first branch-and-bound generative search function (in pre-order, NLMR) on the KSRM coprime pairs trees to find all pairs of coprime (positive) integers not exceeding the given integer :math:`n \\geq 1`.
     
         See the :py:meth:`~continuedfractions.sequences.KSRMTree.search_root`
@@ -590,6 +836,8 @@ class KSRMTree:
         :py:meth:`~continuedfractions.sequences.KSRMTree.search_root` for the
         two canonical roots :math:`(2, 1)` and :math:`(3, 1)`.
 
+        The two KSRM trees are actually only traversed if :math:`n > 3`.
+
         Parameters
         ----------
         n : int
@@ -615,7 +863,7 @@ class KSRMTree:
         >>> list(tree.search("not an integer"))
         Traceback (most recent call last):
         ...
-        ValueError: `n` must be a positive integer >= 1
+        ValueError: `n` must be a positive integer.
         >>> list(tree.search(1))
         [(1, 1)]
         >>> list(tree.search(2))
@@ -628,27 +876,33 @@ class KSRMTree:
         [(1, 1), (2, 1), (3, 2), (4, 3), (5, 4), (6, 5), (7, 6), (8, 7), (9, 8), (8, 3), (7, 2), (5, 2), (8, 5), (9, 2), (4, 1), (7, 4), (9, 4), (6, 1), (8, 1), (3, 1), (5, 3), (7, 5), (9, 7), (7, 3), (5, 1), (9, 5), (7, 1), (9, 1), (10, 9), (10, 7), (10, 3), (10, 1)]
         """
         if not isinstance(n, int) or n < 1:
-            raise ValueError("`n` must be a positive integer >= 1")
-
-        yield 1, 1
+            raise ValueError("`n` must be a positive integer.")
 
+        if n == 1:
+            yield (1, 1)
         if n == 2:
-            yield 2, 1
-        elif n > 1:
-            yield from self.search_root(n - 1, self.roots[0])
-
-        if n > 2:
-            yield from self.search_root(n - 1, self.roots[1])
-            yield from tuple(product([n], _coprime_integers(n)))
+            yield from ((1, 1), (2, 1))
+        elif n == 3:
+            yield from ((1, 1), (2, 1), (3, 2), (3, 1))
+        elif n > 3:
+            yield from chain(
+                ((1, 1),),
+                self.search_root(n - 1, self.roots[0]),
+                self.search_root(n - 1, self.roots[1]),
+                ((n, i) for i in _coprime_integers(n))
+            )
 
 
-def coprime_pairs(n: int, /) -> typing.Generator[KSRMNode, None, None]:
-    """Generates a sequence (tuple) of all pairs of (positive) coprime integers :math:`<= n`.
+def coprime_pairs(n: int, /) -> typing.Generator[tuple[int, int], None, None]:
+    """Generates a sequence (tuple) of all pairs :math:`(a, b)` of (positive) coprime integers :math:`a, b` such that :math:`a, b <= n`.
 
-    Calls the KSRM tree :py:meth:`~continuedfractions.sequences.KSRMTree.search`
-    to perform the search up to :math:`n - 1` and then uses the private function
-    :py:func:`~continuedfractions.sequences._coprime_integers` for the search
-    for pairs involving :math:`n`.
+    This is a simple but fast implementation of the naive :math:`\\bigO(n^2)``
+    algorithm for finding pairs of coprime integers which do not exceed a given
+    positive integer :math:`n`.
+
+    It does **not** call on the
+    :py:meth:`~continuedfractions.sequences.KSRMTree.search` method, which is
+    not as fast as this one.
 
     A :py:class:`ValueError` is raised if ``n`` is not an :py:class:`int`
     or is an :py:class:`int` less than :math:`1`.
@@ -680,29 +934,36 @@ def coprime_pairs(n: int, /) -> typing.Generator[KSRMNode, None, None]:
     >>> tuple(coprime_pairs(2))
     ((1, 1), (2, 1))
     >>> tuple(coprime_pairs(3))
-    ((1, 1), (2, 1), (3, 2), (3, 1))
+    ((1, 1), (2, 1), (3, 1), (3, 2))
     >>> tuple(coprime_pairs(5))
-    ((1, 1), (2, 1), (3, 2), (3, 1), (4, 3), (4, 1), (5, 4), (5, 3), (5, 2), (5, 1))
+    ((1, 1), (2, 1), (3, 1), (3, 2), (4, 1), (4, 3), (5, 1), (5, 2), (5, 3), (5, 4))
     >>> tuple(coprime_pairs(10))
-    ((1, 1), (2, 1), (3, 2), (4, 3), (5, 4), (6, 5), (7, 6), (8, 7), (8, 3), (7, 2), (5, 2), (8, 5), (4, 1), (7, 4), (6, 1), (8, 1), (3, 1), (5, 3), (7, 5), (7, 3), (5, 1), (7, 1), (9, 8), (9, 7), (9, 5), (9, 4), (9, 2), (9, 1), (10, 9), (10, 7), (10, 3), (10, 1))
+    ((1, 1), (2, 1), (3, 1), (3, 2), (4, 1), (4, 3), (5, 1), (5, 2), (5, 3), (5, 4), (6, 1), (6, 5), (7, 1), (7, 2), (7, 3), (7, 4), (7, 5), (7, 6), (8, 1), (8, 3), (8, 5), (8, 7), (9, 1), (9, 2), (9, 4), (9, 5), (9, 7), (9, 8), (10, 1), (10, 3), (10, 7), (10, 9))
+    >>> tuple(coprime_pairs("invalid input"))
+    Traceback (most recent call last):
+    ...
+    ValueError: `n` must be a positive integer
     """
     if not isinstance(n, int) or n < 1:
-        raise ValueError("`n` must be a positive integer >= 1")
+        raise ValueError("`n` must be a positive integer")
 
-    if n == 1:
-        yield (1, 1)
-    else:
-        yield from chain(
-            KSRMTree().search(n - 1),
-            product([n], _coprime_integers(n))
-        )
+    yield (1, 1)
+
+    for i in range(1, n + 1):
+        for j in (_j for _j in range(1, i) if _j < i and math.gcd(i, _j) == 1):
+            yield (i, j)
 
 
-def farey_sequence(n: int, /) -> typing.Generator[ContinuedFraction, None, None]:
+class FareyFraction(ContinuedFraction):
+    """A simple wrapper class for Farey fractions, subclassing :py:class:`~continuedfractions.continuedfraction.ContinuedFraction`.
+    """
+
+
+def farey_sequence(n: int, /) -> typing.Generator[FareyFraction, None, None]:
     """Generates an (ordered) sequence (tuple) of rational numbers forming the Farey sequence of order :math:`n`.
 
     The elements of the sequence are yielded as
-    :py:class:`~continuedfractions.continuedfraction.ContinuedFraction`
+    :py:class:`~continuedfractions.sequences.FareyFraction`
     instances, in ascending order of magnitude.
 
     See the `documentation <https://continuedfractions.readthedocs.io/en/latest/sources/sequences.html#sequences-farey-sequences>`_
@@ -720,46 +981,39 @@ def farey_sequence(n: int, /) -> typing.Generator[ContinuedFraction, None, None]
 
     Yields
     ------
-    ContinuedFraction
+    FareyFraction
         A sequence of
-        :py:class:`~continuedfractions.continuedfraction.ContinuedFraction`
+        :py:class:`~continuedfractions.sequences.FareyFraction`
         instances representing the elements of the Farey sequence of order
         :math:`n`, in ascending order of magnitude.
 
     Examples
     --------
     >>> tuple(farey_sequence(1))
-    (ContinuedFraction(0, 1), ContinuedFraction(1, 1))
+    (FareyFraction(0, 1), FareyFraction(1, 1))
     >>> tuple(farey_sequence(2))
-    (ContinuedFraction(0, 1), ContinuedFraction(1, 2), ContinuedFraction(1, 1))
+    (FareyFraction(0, 1), FareyFraction(1, 2), FareyFraction(1, 1))
     >>> tuple(farey_sequence(3))
-    (ContinuedFraction(0, 1), ContinuedFraction(1, 3), ContinuedFraction(1, 2), ContinuedFraction(2, 3), ContinuedFraction(1, 1))
+    (FareyFraction(0, 1), FareyFraction(1, 3), FareyFraction(1, 2), FareyFraction(2, 3), FareyFraction(1, 1))
     >>> tuple(farey_sequence(4))
-    (ContinuedFraction(0, 1), ContinuedFraction(1, 4), ContinuedFraction(1, 3), ContinuedFraction(1, 2), ContinuedFraction(2, 3), ContinuedFraction(3, 4), ContinuedFraction(1, 1))
+    (FareyFraction(0, 1), FareyFraction(1, 4), FareyFraction(1, 3), FareyFraction(1, 2), FareyFraction(2, 3), FareyFraction(3, 4), FareyFraction(1, 1))
     >>> tuple(farey_sequence(5))
-    (ContinuedFraction(0, 1), ContinuedFraction(1, 5), ContinuedFraction(1, 4), ContinuedFraction(1, 3), ContinuedFraction(2, 5), ContinuedFraction(1, 2), ContinuedFraction(3, 5), ContinuedFraction(2, 3), ContinuedFraction(3, 4), ContinuedFraction(4, 5), ContinuedFraction(1, 1))
+    (FareyFraction(0, 1), FareyFraction(1, 5), FareyFraction(1, 4), FareyFraction(1, 3), FareyFraction(2, 5), FareyFraction(1, 2), FareyFraction(3, 5), FareyFraction(2, 3), FareyFraction(3, 4), FareyFraction(4, 5), FareyFraction(1, 1))
     """
     if not isinstance(n, int) or n < 1:
-        raise ValueError("`n` must be a positive integer >= 1")
+        raise ValueError("`n` must be a positive integer")
 
     if n == 1:
-        yield from (ContinuedFraction(0, 1), ContinuedFraction(1, 1))
+        yield from (FareyFraction(0, 1), FareyFraction(1, 1))
     else:
-        yield from chain(
-            (ContinuedFraction(0, 1),),
-            sorted(
-                starmap(
-                    ContinuedFraction,
-                    starmap(lambda *x: tuple(reversed(x)), coprime_pairs(n))
-                )
-            )
-        )
+        yield FareyFraction(0, 1)
+        yield from sorted(FareyFraction(q, p) for (p, q) in coprime_pairs(n))
 
 
 if __name__ == "__main__":      # pragma: no cover
     # Doctest the module from the project root using
     #
-    #     python -m doctest -v src/continuedfractions/sequences.py
+    #     PYTHONPATH="src" python3 -m doctest -v src/continuedfractions/sequences.py
     #
     import doctest
     doctest.testmod()
